sys_mprotect

Function sys_mprotect 

#[unsafe(no_mangle)]
pub extern "C" fn sys_mprotect( ptr: *mut u8, size: usize, prot_flags: MemoryProtection, ) -> i32
Available on crate feature mman only.
Configures the protections associated with a region of virtual memory starting at ptr and going to size.

Returns 0 on success and an error code on failure.